% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Codes.R
\name{TestForDistalGrowth}
\alias{TestForDistalGrowth}
\title{Test for distal growth}
\usage{
TestForDistalGrowth(alpha = 0.05, gamma, epsilon = 0.15,
  parametric = TRUE, nr_fingers = 8, nr_printsPerFinger = 7)
}
\arguments{
\item{alpha}{Confidence level.}

\item{gamma}{Vector of angles in [0, pi).}

\item{epsilon}{Doubled alignment precision for fingerprints (for parametric test only).}

\item{parametric}{Boolean value, \code{TRUE} if parametric test is used.}

\item{nr_fingers}{Number of fingers (for non-parametric test only).}

\item{nr_printsPerFinger}{Number of fingerprints per finger (for non-parametric test only).}
}
\description{
Parametric and non-parametric test for distal growth.
}
\examples{

# generating top and bottom values of a .95 % critical region for anisotropic growth (tau = 0.5)

# bottom value for the parametric test
      rejects <- c()
      for (gamma_value in seq(from=-0.0235, to=-0.023, by=0.0001)) {
	tau <- 0.05
	OtherFingersGrown <- SimulateAnisotropicGrowth(OtherFingersOrientedCentered,gamma = gamma_value,taus = tau,lambdas=1)
	gamma <- AnisotropicGrowthEstimation(FirstFingers = FirstFingersCentered, OtherFingersGrown)$gamma
	rejects <- c(rejects,TestForDistalGrowth(gamma)$rejected); print(gamma_value)
      } 
# top value for the parametric test
      rejects <- c()
      for (gamma_value in seq(from=0.021, to=0.022, by=0.0001)) {
	tau <- 0.05
	OtherFingersGrown <- SimulateAnisotropicGrowth(OtherFingersOrientedCentered,gamma = gamma_value,taus = tau,lambdas=1)
	gamma <- AnisotropicGrowthEstimation(FirstFingers = FirstFingersCentered, OtherFingersGrown)$gamma
	rejects <- c(rejects,TestForDistalGrowth(gamma)$rejected); print(gamma_value)
      } 
 
# bottom and top value for the nonparametric test       
     rejects <- c()
     set.seed(1)
     for (gamma_value in c(-250,250)*pi/250 {
	tau <- 0.05
	OtherFingersGrown <- SimulateAnisotropicGrowth(OtherFingersOrientedCentered,gamma = gamma_value,taus = tau,lambdas=1)
	gamma <- AnisotropicGrowthEstimation(FirstFingers = FirstFingersCentered, OtherFingersGrown)$gamma
	rejects <- c(rejects,TestForDistalGrowth(gamma,parametric=FALSE)$rejected);  print(gamma_value)
      } 
}