% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Codes.R
\name{TestForGamma}
\alias{TestForGamma}
\title{Test for gamma}
\usage{
TestForGamma(gamma, alpha = 0.05)
}
\arguments{
\item{gamma}{Vector of angles in [0, pi).}

\item{alpha}{Confidence level.}
}
\value{A list with components
\item{reject}{TRUE if null-hypothesis is rejected, else FALSE.}
\item{test.statistic}{the value of the Rayleigh test statistic.}
\item{critical.value}{the 1-alpha quantile of the chisquare distribution with two degrees of freedom.}
\item{p.value}{the p.value of the Rayleigh test statistic.}
}

\description{
Rayleigh-test for anisotropy of gamma. Null-hypothesis: There is no anisotropic growth effect.
}
\examples{
# validation (fingerprint data)
TestForGamma(AnisotropicGrowthEstimation(FirstFingersCentered, OtherFingersCentered)$gamma)

# validation (simulated Poisson point clouds with varying isotropic growth and aspect ratios      
set.seed(1)
rejects05 <- 0; rejects01 <- 0; p <-1
  for (j in 1:30) {
    for (xmax in c(30,50,100,200,300)) {
      for (lambdas in c(1,2,3,4)) {
	generatedFingers <- SimulatePoissonFingers(xlimits=c(-xmax,xmax), ylimits=c(-100,100))
	OtherFingersGrown <- SimulateAnisotropicGrowth(generatedFingers$OtherFingers,lambdas=lambdas) 
	A<-AnisotropicGrowthEstimation(generatedFingers$FirstFingers, OtherFingersGrown)
	pp <- TestForGamma(gamma=A$gamma)$p.value
	if (pp > 0.99) rejects01 <- rejects01 +1
	if (pp > 0.95) rejects05 <- rejects05 +1
	print(c(p,pp,rejects05,rejects01))
	p <- p+1
}}}


# sensitivity analysis
tau_values = c()
for (gamma_value in seq(0,pi,length=20)){
      gamma_value = gamma_value + pi/2 #since the fingers are oriented towards north
      tau = 0
      while (TestForGamma(AnisotropicGrowthEstimation(FirstFingers = FirstFingersCentered, OtherFingers = SimulateAnisotropicGrowth(OtherFingersOrientedCentered,gamma = gamma_value,taus = tau,lambdas=1))$gamma - pi/2, alpha = 0.05)$reject == FALSE){
	  tau = tau + 0.001
      }
      tau_values = c(tau_values, tau)
}
plot(seq(0,pi,length = 20),tau_values, pch = 20, xlab=expression(gamma),ylab=expression(tau))

}
