% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Codes.R
\name{TestForTau}
\alias{TestForTau}
\title{Test for tau}
\usage{
TestForTau(tau, reference_taus, alpha = 0.05)
}
\arguments{
\item{tau}{Vector wih rates of anisotropic growth.}

\item{reference_taus}{Vector with rates of simulated isotropic growth.}

\item{alpha}{Confidence level.}
}
\value{A list with components
\item{reject}{TRUE if null-hypothesis is rejected, else FALSE.}
\item{p.value}{the p.value of the Kolmogorov-Smirnov statistic.}
\item{alpha}{Confidence level.}
}
\description{
Kolmogorov-Smirnov goodness of fit test for equality of distributions. Null-hypothesis: There is no anisotropic growth effect.
}
\examples{
set.seed(1) 
generatedFingers = SimulatePoissonFingers()
reference_taus = AnisotropicGrowthEstimation(generatedFingers$FirstFingers, generatedFingers$OtherFingers)$tau
TestForTau(AnisotropicGrowthEstimation(FirstFingersCentered, OtherFingersCentered)$tau, reference_taus)

# validation (simulation)
tau = AnisotropicGrowthEstimation(FirstFingersCentered, OtherFingersCentered)$tau
set.seed(1) 
rejects05 <- 0; rejects01 <- 0
for  (jj in 1:1000) {
      generatedFingers = SimulatePoissonFingers(xlimits=c(-95,95), ylimits=c(-165,165), sigma=7,poissonExpectedValue = 22)
      sim_taus = AnisotropicGrowthEstimation(generatedFingers$FirstFingers, generatedFingers$OtherFingers)$tau
      pp <- TestForTau(tau, reference_taus = sim_taus)$p.value
      if (pp < 0.01) rejects01 <- rejects01 +1
      if (pp < 0.05) rejects05 <- rejects05 +1
      print(c(pp,jj,rejects05,rejects01))
  }

# sensitivity analysis

set.seed(1)
generatedFingers = SimulatePoissonFingers()
sim_taus = AnisotropicGrowthEstimation(generatedFingers$FirstFingers, generatedFingers$OtherFingers)$tau
TestForTau(tau = AnisotropicGrowthEstimation(FirstFingersCentered, OtherFingersCentered)$tau, reference_taus = sim_taus)
tau_values = c()
generatedFingers = SimulatePoissonFingers(use_seed = TRUE)
sim_taus = AnisotropicGrowthEstimation(generatedFingers$FirstFingers, generatedFingers$OtherFingers)$tau
for (gamma_value in seq(0, pi, length=20)){
  gamma_value = gamma_value - pi/2
  tau = 0
  TestForTau(tau = AnisotropicGrowthEstimation(FirstFingers = FirstFingersCentered, OtherFingers = SimulateAnisotropicGrowth(OtherFingersOrientedCentered,gamma = gamma_value,taus = tau,lambdas=1))$tau, reference_taus = sim_taus)
  while (TestForTau(tau = AnisotropicGrowthEstimation(FirstFingers = FirstFingersCentered, OtherFingers = SimulateAnisotropicGrowth(OtherFingersOrientedCentered,gamma = gamma_value,taus = tau,lambdas=1))$tau, reference_taus = sim_taus)$reject == TRUE){
      tau = tau + 0.001
  }
  tau_values = c(tau_values, tau)
}
plot(seq(0,pi,length = 20),tau_values, pch = 20, xlab=expression(gamma),ylab=expression(tau))


}
